#!/usr/bin/env python
# Copyright (c) 2011 Red Hat, Inc. All rights reserved. This copyrighted material
# is made available to anyone wishing to use, modify, copy, or
# redistribute it subject to the terms and conditions of the GNU General
# Public License v.2.
#
# This program is distributed in the hope that it will be useful, but WITHOUT ANY
# WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
# PARTICULAR PURPOSE. See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
#
# Author: Greg Nichols <gnichols@redhat.com>
#
# HTTP file upload for rhcert's tests

import os
import time
import sys
import requests


class HttpUpload:

    def __init__(self, host, url):
        self.host = host
        self.url = url
        self.fields = {}
        self.files = {}
        self.log = sys.stdout
        self.errorLog = sys.stderr

    def addFile(self, filepath, name="file"):
        try:
            self.files[name] = open(filepath, 'rb')
        except Exception as error:
            self.errorLog.write(str(error))
            return False
        return True

    def addField(self, name, value):
        self.fields[name]= value
        return True

    def send(self):
        startTime = time.time()
        result = requests.post("http://" + self.host + self.url, files=self.files, data=self.fields)
        stopTime = time.time()
        if result.status_code != 200:
            # send failed
            self.errorLog.write("Error: File upload failed with status code %s" % result.status_code)
            return result
        self.log.write("response: \n")
        self.log.write(result.text)
        self.log.write("\nUpload took %.2f seconds\n" % (stopTime-startTime))
        return result

    def httpUpload(self, localFilePath, log=sys.stdout):
        self.log = log
        if log != sys.stdout:
            self.errorLog = log
        if not self.addFile(localFilePath):
            self.log.write("Error: could not add file %s to request\n" % localFilePath)
            return False
        # otherwise
        self.log.write("sending file %s \n" % localFilePath)
        return self.send()


if __name__ == "__main__":

    request = HttpUpload("localhost", "/save")
    serverPath = os.path.join("/var/www/rhcert", "Constants.store", "transfer")
    request.addField("server-path", serverPath)
    request.addFile("httpUpload.py")
    result = request.send()
    print(result.headers)
