# This file fills in the gaps in HAL's knowledge about system hardware.

import os,re,string

# These functions are from hardware.py
def read_memory():
    "Return a dict containing ram and swap size (in MB)"
    un = os.uname()
    kernel = un[2]
    if kernel[:3] == "2.6":
        return read_memory_2_6()
    if kernel[:3] == "2.4":
        return read_memory_2_4()

def read_memory_2_4():
    if not os.access("/proc/meminfo", os.R_OK):
        return {}

    meminfo = open("/proc/meminfo", "r").read()
    lines = string.split(meminfo,"\n")
    curline = lines[1]
    memlist = string.split(curline)
    memdict = {}
    memdict['class'] = "MEMORY"
    megs = int(long(memlist[1])/(1024*1024))
    if megs < 32:
        megs = megs + (4 - (megs % 4))
    else:
        megs = megs + (16 - (megs % 16))
    memdict['ram'] = str(megs)
    curline = lines[2]
    memlist = string.split(curline)
    # otherwise, it breaks on > ~4gigs of swap
    megs = int(long(memlist[1])/(1024*1024))
    memdict['swap'] = str(megs)
    return memdict

def read_memory_2_6():
    if not os.access("/proc/meminfo", os.R_OK):
        return {}
    meminfo = open("/proc/meminfo", "r").read()
    lines = string.split(meminfo,"\n")
    dict = {}
    for line in lines:
        blobs = string.split(line, ":", 1)
        key = blobs[0]
        if len(blobs) == 1:
            continue
        #print blobs
        value = string.strip(blobs[1])
        dict[key] = value

    memdict = {}
    memdict["class"] = "MEMORY"

    total_str = dict['MemTotal']
    blips = string.split(total_str, " ")
    total_k = long(blips[0])
    megs = long(total_k/(1024))

    swap_str = dict['SwapTotal']
    blips = string.split(swap_str, ' ')
    swap_k = long(blips[0])
    swap_megs = long(swap_k/(1024))

    memdict['ram'] = str(megs)
    memdict['swap'] = str(swap_megs)
    return memdict

def s390_hardware():
    "Fill in missing information about s390 hardware."
    s390_hw={}
    # TAPE
    if os.path.isdir('/proc/s390dbf/tape'):
        # FIXME: don't just assume it will be ntibm0
        s390_hw['TAPE']=['ntibm0']
    # Z90CRYPT
    if os.path.isfile('/proc/driver/z90crypt'):
        # no device name necessary
        s390_hw['Z90CRYPT']=[]
    # HD (DASD)
    f=open('/proc/dasd/devices')
    dasd=[t for line in f for t in line.split() if t[:4]=='dasd']
    f.close()
    s390_hw['HD']=dasd
    # NETWORK (QETH)
    f=open('/proc/chandev')
    eth=[t for line in f for t in line.split() if t[:3]=='eth']
    f.close()
    s390_hw['NETWORK']=eth

    return s390_hw

def network_speed(dev):
    "Attempt to determine the speed of a NIC"
    speed=100 # fallback guess: 100mbit
    p=os.popen("ethtool %s" % dev)
    [line]=[l.strip() for l in p.readlines() if 'Speed:' in l]
    if p.close() != None:
        p=os.popen("mii-tool %s" % dev)
        line=p.readline().strip(dev+": \t\n")
        p.close()
    if line:
        speed=re.search('\d+',line).group()
    return speed
