 # Copyright (c) 2014 Red Hat, Inc. All rights reserved. This copyrighted material 
# is made available to anyone wishing to use, modify, copy, or 
# redistribute it subject to the terms and conditions of the GNU General 
# Public License v.2.
# 
# This program is distributed in the hope that it will be useful, but WITHOUT ANY
# WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
# PARTICULAR PURPOSE. See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
#
# Author: Greg Nichols <gnichols@redhat.com>
#
# remote.py: a test driver utility for rhcert-client's listener.py

import xmlrpclib
from optparse import OptionParser

from rhcert.tags import Constants, TestTag

class Remote():

    def __init__(self):
        parser = OptionParser()
        parser.add_option("-n","--server",action="store", type="string", dest="server",
                        help="Remote test host")
        parser.add_option("-i","--udi", action="append", type="string", dest="udi",
                        help="UDI - the unique device ID")
        # note that "forced" mode is not allowed on the command line, but is valid
        parser.add_option("-m","--mode", action="store", type="choice", choices=(Constants.normal, Constants.auto), dest="mode",
                        help="Test Mode: normal, auto")
        parser.add_option("-t","--test", action="append", type="string", dest="test",
                        help="Test Name")
        parser.add_option("-o", "--report",
                          action="store", type="choice", choices=(Constants.plan, Constants.summary, Constants.full, Constants.device),
                          dest="report", default=Constants.summary,
                          help="The type of report to print.")
        parser.add_option("-b", "--debug", type="choice", choices=(Constants.off, Constants.low, Constants.medium, Constants.high),
                          action="store", dest="debug", default=Constants.off,
                          help="Enable debugging output")
        parser.add_option("-v", "--device",
                          action="store", type="string", dest="device",
                          help="The logical device to be tested.")
        # default is TestTag.certification, set explicitly below because optparse doesn't do the right thing
        parser.add_option("-g", "--tag",
                          action="append", type="choice", choices=TestTag.getAll())

        parser.set_defaults(mode="auto")
        (self.options, self.args) = parser.parse_args()

    def setOptions(self, options):
        """ set options using a dict """
        for (name, value) in options.items():
            self.options.__dict__[name] = value

    def do(self):
        server = xmlrpclib.ServerProxy('http://localhost:8000', allow_none=True)

        for method in server.system.listMethods():
            print(server.system.methodSignature(method))
        print("args:")
        print(self.args)
        print("options:")
        print(self.options)
        server.setCommandOptions(self.options, self.args)
        result = server.runCommand()
        if result:
            print("Success!")
        else:
            print("Failed.")

if __name__ == "__main__":

    remote = Remote()
    remote.do()