#!/usr/bin/env python
# Copyright (c) 2019 Red Hat, Inc. All rights reserved. This copyrighted material
# is made available to anyone wishing to use, modify, copy, or
# redistribute it subject to the terms and conditions of the GNU General
# Public License v.2.
#
# This program is distributed in the hope that it will be useful, but WITHOUT ANY
# WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
# PARTICULAR PURPOSE. See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
#
# Author: Greg Nichols
#

from rhcert.tags import Tags, Attributes
from rhcert.model.documentbase import NamedDocumentWrapper
from rhcert.model.hostdocument import HostDocument

class Feature(NamedDocumentWrapper):

    def __init__(self, element, document):
        NamedDocumentWrapper.__init__(self, element, document)

    def getCategory(self):
        return self.element.getAttribute(Attributes.category)
    def setCategory(self, value):
        if value:
            return self.setAttribute(self.element, Attributes.category, value)
        # otherwise
        self.removeAttribute(self.element,Attributes.category)


if __name__ == "__main__":
    from rhcert.model.certificationdocument import CertificationDocument
    doc = CertificationDocument()
    doc.new()
    featureElement = doc.findOrCreateElement(doc.element, Tags.feature)
    feature = Feature(featureElement, doc.document)
    feature.setID(66)
    feature.setName("20G Ethernet")
    feature.setCategory("Network")
    doc.save("featureTest.xml")



