#!/usr/bin/env python
# Copyright (c) 2018 Red Hat, Inc. All rights reserved. This copyrighted material
# is made available to anyone wishing to use, modify, copy, or
# redistribute it subject to the terms and conditions of the GNU General
# Public License v.2.
#
# This program is distributed in the hope that it will be useful, but WITHOUT ANY
# WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
# PARTICULAR PURPOSE. See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
#
# Author: Greg Nichols
#

from rhcert.tags import Tags, Attributes
from rhcert.model.documentbase import NamedDocumentWrapper

"""
<xs:complexType name="os">
    <xs:complexType>
        <xs:sequence>
            <xs:element name="name" type="xs:string"/>
            <xs:element name="release" type="xs:string"/>
            <xs:element name="product" type="xs:string"/>
            <xs:element name="hostname" type="xs:string"/>
            <xs:element name="ip-address" type="xs:string"/>
            <xs:element name="role" type="xs:string"/>
        </xs:sequence>
        <xs:attribute name="name" type="xs:string"/>
        <xs:attribute name="id" type="xs:string"/>
    </xs:complexType>
</xs:complexType>

name attribute: the host's hostname
id attribute:   the host's roleID

hostname sub-element: the host's hostname
name sub-element: the host's OS code name

"""

class HostDocument(NamedDocumentWrapper):

    def __init__(self, element, document):
        NamedDocumentWrapper.__init__(self, element, document)
        # for compatability, set the name attribute with the hostname element if missing
        if not self.element.getAttribute(Attributes.name) and self.getChildElementString(Tags.hostname):
            self.setAttribute(self.element, Attributes.name, self.getChildElementString(Tags.hostname))

    def setName(self, name):
        """ override to also create hostname element as well as name attribute """
        NamedDocumentWrapper.setName(self, name) # sets the "name" attribute
        self.setChildElement(Tags.hostname, name)

    def getName(self):
        return self.getChildElementString(Tags.hostname)

    def getRelease(self):
        return self.getChildElementString(Tags.release)
    def setRelease(self, release):
        self.setChildElement(Tags.release, release)

    def getProduct(self):
        return self.getChildElementString(Tags.product)
    def setProduct(self, product):
        self.setChildElement(Tags.product, product)

    def getCodeName(self):
        return self.getChildElementString(Tags.name)
    def setCodeName(self, codeName):
        self.setChildElement(Tags.name, codeName)

    def getIPAddress(self):
        return self.getChildElementString(Tags.ip_address)
    def setIPAddress(self, ip_address):
        self.setChildElement(Tags.ip_address, ip_address)

    def getRole(self):
        return self.getChildElementString(Tags.role)
    def setRole(self, role):
        self.setChildElement(Tags.role, role)

    def getRoleAndID(self):
        return self.getRole() + '-' + self.getID()

    def getValues(self):
        """ return os element values as dict """
        values = dict()
        for element in self.element.childNodes:
            textNode = self.getTextNode(element)
            if textNode and not textNode.data.isspace():
                values[element.nodeName] = textNode.data
        return values

if __name__ == "__main__":
    pass


