# Copyright (c) 2014 Red Hat, Inc. All rights reserved. This copyrighted material
# is made available to anyone wishing to use, modify, copy, or
# redistribute it subject to the terms and conditions of the GNU General
# Public License v.2.
#
# This program is distributed in the hope that it will be useful, but WITHOUT ANY
# WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
# PARTICULAR PURPOSE. See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
#
# Author: Greg Nichols <gnichols@redhat.com>


from rhcert.tags import Tags, Attributes
from rhcert.model.documentbase import DocumentBase

class ImagePair(DocumentBase):
    """ xml document defining the meta-data for a container image (pair: manifest and image) """
    def __init__(self):
        DocumentBase.__init__(self)

    def new(self):
        self._new(topElement=Tags.image, stylesheet="/rhcert/css/image.css")

    def getCertificationID(self):
        return self.element.getAttribute(Attributes.certification_id)
    def setCertificationID(self, certificationID):
        self.element.setAttribute(Attributes.id, str(certificationID))

    def getDescription(self):
        descriptionElement = self.findOrCreateElement(self.element, Tags.description)
        textNode = self.getTextNode(descriptionElement)
        if textNode and not textNode.data.isspace():
            return textNode.data
        # otherwise
        return ""

    def setDescription(self, description):
        descriptionElement = self.findOrCreateElement(self.element, Tags.description)
        self.setTextNode(descriptionElement, description)

    def getURL(self):
        urlElement = self.findOrCreateElement(self.element, Tags.url)
        textNode = self.getTextNode(urlElement)
        if textNode and not textNode.data.isspace():
            return textNode.data
        # otherwise
        return ""

    def setURL(self, description):
        urlElement = self.findOrCreateElement(self.element, Tags.url)
        self.setTextNode(urlElement, description)

    def getUploadTime(self):
        return self.element.getAttribute(Attributes.upload_time)
    def setUploadTime(self, uploadTime):
        self.element.setAttribute(Attributes.upload_time, self.timeToString(uploadTime))
    def getSubmitTime(self):
        return self.element.getAttribute(Attributes.submit_time)
    def setSubmitTime(self, submitTime):
        self.element.setAttribute(Attributes.submit_time, self.timeToString(submitTime))



