#!/usr/bin/env python
# Copyright (c) 2019 Red Hat, Inc. All rights reserved. This copyrighted material
# is made available to anyone wishing to use, modify, copy, or
# redistribute it subject to the terms and conditions of the GNU General
# Public License v.2.
#
# This program is distributed in the hope that it will be useful, but WITHOUT ANY
# WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
# PARTICULAR PURPOSE. See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
#
# Author: Greg Nichols
#
# ServerSettings: installation settings and status for the RHCert server (LTS)
import sys

from rhcert.tags import Tags, Attributes, Constants
from rhcert.model.documentbase import DocumentBase

class ServerSettingsDocument(DocumentBase):
    """ ServerSettings: installation settings and status for the RHCert server (LTS) """

    def __init__(self, topElement=None, document=None):
        DocumentBase.__init__(self)
        self.element = topElement
        self.document = document

    def new(self):
        self._new(topElement=Tags.server_settings, stylesheet="/rhcert/css/products.css")
        self.setDebug(Constants.off)

    def getDebug(self):
        return self.element.getAttribute(Constants.debug)

    def setDebug(self, value):
        self.setAttribute(self.element, Constants.debug, value)

    def getDialogOrder(self):
        return self.element.getAttribute(Attributes.dialog_order)

    def setDialogOrder(self, value):
        self.setAttribute(self.element, Attributes.dialog_order, value)

    def getSyncStatus(self):
        return self.element.getAttribute(Attributes.sync)

    def setSyncStatus(self, value):
        self.setAttribute(self.element, Attributes.sync, value)

    def getSyncTime(self):
        if not self.element.getAttribute(Attributes.sync_time):
            return "0" # never?
        return self.element.getAttribute(Attributes.sync_time)

    def setSyncTime(self, value):
        self.setAttribute(self.element, Attributes.sync_time, value)

    def getSyncRange(self):
        if not self.element.getAttribute(Attributes.sync_range):
            self.setSyncRange("45") # days
        return self.element.getAttribute(Attributes.sync_range)

    def setSyncRange(self, value):
        self.setAttribute(self.element, Attributes.sync_range, value)

def unitTest():
    return True

if __name__ == "__main__":
    unitTest()
