# Copyright (c) 2006 Red Hat, Inc. All rights reserved. This copyrighted material 
# is made available to anyone wishing to use, modify, copy, or 
# redistribute it subject to the terms and conditions of the GNU General 
# Public License v.2.
# 
# This program is distributed in the hope that it will be useful, but WITHOUT ANY
# WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
# PARTICULAR PURPOSE. See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
#
# Author: Greg Nichols
#
from rhcert.tags import Tags, Attributes
from rhcert.model.documentbase import DocumentWrapper

class TestParameters(DocumentWrapper):

    def __init__(self, parametersElement=None, document=None):
        self.element = parametersElement
        self.document = document
        self.parameters = dict()

    def __str__(self):
        message = ""
        for (key, value) in self.getAll().items():
            message += "%s=%s " % (key, value)
        return message

    def copy(self, testParameters):
        self.element = None
        self.document = None
        self.parameters = testParameters.getAll()

    def save(self, parametersElement, document):
        self.element = parametersElement
        self.document = document
        for (key, value) in self.parameters.items():
            self.set(key, value)

    def get(self, name):
        parameters = self.getAll()
        try:
            return parameters[name]
        except KeyError:
            return None

    def set(self, name, value):
        self.parameters[name] = value

        if self.element and self.document:
            propertyElements = self.getChildElements(Tags.property)
            for propertyElement in propertyElements:
                if name == propertyElement.getAttribute(Attributes.name):
                    self.setTextNode(propertyElement, value)
                    return
            # otherwise, add the property
            propertyElement = self.document.createElement(Tags.property)
            propertyElement.setAttribute(Attributes.name, name)
            self.setTextNode(propertyElement, value)
            self.element.appendChild(propertyElement)

    def getAll(self):
        if not self.element or not self.document:
            return self.parameters
        # otherwise
        propertyElements = self.getChildElements(Tags.property)
        self.parameters = dict()
        for propertyElement in propertyElements:
            value = self.getTextNode(propertyElement)
            name = propertyElement.getAttribute(Attributes.name)
            if name and value:
                self.parameters[name] = value.data
        return self.parameters

    def getElement(self):
        return self.element

    def dump(self):
        print(self.element.toxml())
