#!/usr/bin/env python
# Copyright (c) 2015 Red Hat, Inc. All rights reserved. This copyrighted material 
# is made available to anyone wishing to use, modify, copy, or 
# redistribute it subject to the terms and conditions of the GNU General 
# Public License v.2.
# 
# This program is distributed in the hope that it will be useful, but WITHOUT ANY
# WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
# PARTICULAR PURPOSE. See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
#
# Author: Greg Nichols
#

from rhcert.tags import Tags, Attributes
from rhcert.model.documentbase import NamedDocumentWrapper
from rhcert.model.productdocument import ProductDocument

class VendorDocument(NamedDocumentWrapper):

    def __init__(self, element, document):
        NamedDocumentWrapper.__init__(self, element, document)

    def serialize(self):
        return {
            'id': self.getID(),
            'name': self.getName(),
        }

    def __getNextScratchID(self):
        scratchID = self.element.getAttribute(Attributes.scratch_id)
        self.setAttribute(self.element, Attributes.scratch_id, (int(scratchID)+1))
        return scratchID

    def getWorkflow(self):
        return self.element.getAttribute(Attributes.workflow)
    def setWorkflow(self, workflow):
        if workflow:
            self.setAttribute(self.element, Attributes.workflow, workflow)

    def isPassThrough(self):
        if self.element.getAttribute(Attributes.pass_through_vendor):
            return True
        return False

    def setPassThrough(self):
        self.setAttribute(self.element, Attributes.pass_through_vendor, True)
        return True

    def isPublic(self):
        if self.element.getAttribute(Attributes.public):
            return True
        return False

    def setPublic(self):
        self.setAttribute(self.element, Attributes.public, True)
        return True

    def getProducts(self):
        products = list()
        for element in self.getChildElements(Tags.product):
            products.append(ProductDocument(element, self.document))
        return products

    def getProduct(self, productID):
        for product in self.getProducts():
            if product.getID() == str(productID):
                return product
        return None

    def getProductByName(self, productName):
        for product in self.getProducts():
            if product.getName() == productName:
                return product
        return None

    def createProduct(self, name, productID=None):
        if productID and self.getProduct(productID):
            return self.getProduct(productID)

        # otherwise
        productElement = self.document.createElement(Tags.product)
        self.element.appendChild(productElement)
        product = ProductDocument(productElement, self.document)
        if not productID:
            productID = self.__getNextScratchID()
        product.setID(productID)
        product.setName(name)
        return product

    def copyProduct(self, originalProductDocument):
        product = self.getProduct(originalProductDocument.getID())
        if product:
            return product

        productElementCopy = self.document.importNode(originalProductDocument.element, True) # True = deep copy
        self.element.appendChild(productElementCopy)
        return VendorDocument(productElementCopy, self.document)

        return None

    def setProduct(self, product):
        """ product = ProductDocument """
        # delect existing products
        for productElement in self.getChildElements(Tags.product):
            self.element.removeChild(productElement)
        productElementCopy = self.mergeDocument(product, self.element)
        return ProductDocument(productElementCopy, self.document)

def unitTest():
    vendor = VendorDocument()
    vendor.new()
    vendorFile=open("vendor.xml","w")
    vendor.save(vendorFile)


if __name__ == "__main__":
    unitTest()
    print("saved qq.xml")
