# Copyright (c) 2020 Red Hat, Inc. All rights reserved. This copyrighted material
# is made available to anyone wishing to use, modify, copy, or
# redistribute it subject to the terms and conditions of the GNU General
# Public License v.2.
#
# This program is distributed in the hope that it will be useful, but WITHOUT ANY
# WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
# PARTICULAR PURPOSE. See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
#
# Author: Petersingh Anburaj

from optparse import OptionParser
from optparse import Option, OptionValueError


class RHCertOption(Option):
    """
    A custom action to parse arguments as key=value pairs
    """
    ACTIONS = Option.ACTIONS + ("KeyValuePair",)
    STORE_ACTIONS = Option.STORE_ACTIONS + ("KeyValuePair",)
    TYPED_ACTIONS = Option.TYPED_ACTIONS + ("KeyValuePair",)
    ALWAYS_TYPED_ACTIONS = Option.ALWAYS_TYPED_ACTIONS + ("KeyValuePair",)

    def take_action(self, action, dest, opt, value, values, parser):
        if action == "KeyValuePair":
            if '=' in value:
                value_list = value.split('=', 1)
                if '' == value_list[0]:
                    msg = "Key must be specified: %s"
                    raise OptionValueError(msg % str(value))
                else:
                    values.ensure_value(dest, {}).update([value_list])
            else:
                msg = "Expected 'key=value' type, but got: %s"
                raise OptionValueError(msg % str(value))
        else:
            Option.take_action(self, action, dest, opt, value, values, parser)


class RHCertOptionParser(OptionParser):
    def __init__(self, rhcert, usage):
        self.rhcert = rhcert
        OptionParser.__init__(self, usage=usage, option_class=RHCertOption)

    def print_help(self):
        self.rhcert.showHelp()
