# Copyright (c) 2017 Red Hat, Inc. All rights reserved. This copyrighted material
# is made available to anyone wishing to use, modify, copy, or
# redistribute it subject to the terms and conditions of the GNU General
# Public License v.2.
#
# This program is distributed in the hope that it will be useful, but WITHOUT ANY
# WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
# PARTICULAR PURPOSE. See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
#
# Author: Yanis Guenane  <yguenane@redhat.com>

from rhcert.controller import Controller
from rhcert.tags import Constants, Tags
from xml.sax.saxutils import escape


class ReportJunit(Controller):

    def __init__(self, options, certification):
        self.certification = certification
        self.options = options

    def Write(self):
        junit_result = '<?xml version="1.0" encoding="UTF-8"?>'

        if not self.certification:
            junit_result += self.empty_testsuite()
        else:
            for run_id in range(self.certification.getNumberOfTestRuns()):
                junit_result += self.run_testsuite(run_id + 1)

        print(junit_result)
        return True

    def run_testsuite(self, run_id):
        tests = self.certification.getTests()
        counts = self.certification.getTestCounts(run_id)
        counts['skipped'] = counts['count'] - counts['run']
        junit_result = """
<testsuite disabled="0" errors="0" failures="%s" name="%s" skipped="%s" tests="%s" time="0" timestamp="0">
%s
</testsuite>
""" % (counts['failed'], Constants.certification_label, counts['skipped'], counts['count'], self.WriteTestRun(tests, run_id))

        return junit_result

    def empty_testsuite(self):
        return """
<testsuite disabled="0" errors="0" failures="0" name="%s" skipped="0" tests="0" time="0" timestamp="0">
</testsuite>
""" % Constants.certification_label

    def WriteTestRun(self, tests, runNumber):
        junit_result = ''
        for test in tests:
            run = test.getRun(runNumber)
            if run:
                summary = run.getSummary()
            else:
                summary = 'SKIPPED'

            if summary in ('PASS', 'REVIEW'):
                testcase = '<testcase classname="%s" name="%s" time="0.00"/>' % (
                    escape(test.getName()), escape(test.getName()))
            elif summary == 'FAIL':
                testcase = '<testcase classname="%s" name="%s" time="0.00">\n<failure>%s</failure>\n</testcase>' % (
                    escape(test.getName()),
                    escape(test.getName()),
                    escape(self.generate_failure_log(test.getName(), run)))
            else:
                testcase = '<testcase classname="%s" name="%s" time="0.00">\n<skipped>%s not activated</skipped>\n</testcase>' % (
                    escape(test.getName()),
                    escape(test.getName()),
                    escape(test.getName()))

            junit_result += '%s' % testcase

        return junit_result

    def generate_failure_log(self, test_name, run):

        to_return = "Summary:\n\n"
        for subtest in run.getSubTestOutputDocuments():
            to_return += '%s - %s: %s\n' % (subtest.getName(),
                                            subtest.getDescription(),
                                            subtest.getSummary())

        to_return += '\nFull log:\n\n %s\n' % run.getTestOutput()
        return to_return

    def WriteSubCertification(self, subCertification):
        pass

    def WriteTestPlan(self):
        pass

    def formatTest(self, test):
        pass
