# Copyright (c) 2006 Red Hat, Inc. All rights reserved. This copyrighted material 
# is made available to anyone wishing to use, modify, copy, or 
# redistribute it subject to the terms and conditions of the GNU General 
# Public License v.2.
# 
# This program is distributed in the hope that it will be useful, but WITHOUT ANY
# WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
# PARTICULAR PURPOSE. See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
#
# Author: Greg Nichols
#
#


class ResultsEngine:

    def __init__(self, certification):
        self.certification = certification


    def getRemainingTests(self, catalog):
        tests = self.certification.getTests()
        mandatoryTests = self.certification.getMandatoryTests()
        passedTests = dict()
        for runNumber in range(1, self.certification.getNumberOfTestRuns()+1):
            runTests = self.certification.getTestsRun(runNumber)
            disqualified = False
            for mandatoryTest in mandatoryTests:
                if not mandatoryTest.getRun(runNumber):
                    print("Warning: test run %s is disqualified due to missing mandatory test %s" %  (runNumber, mandatoryTest.getName()))
                    disqualified = True
                elif not mandatoryTest.getRun(runNumber).passed():
                    print("Warning: test run %s is disqualified due to mandatory test %s failure" % (runNumber, mandatoryTest.getName()))
                    disqualified = True

            if disqualified:
                continue

            # passed any mandatory tests - add passed tests to the list
            for test in runTests:
                if test.getRun(runNumber).passed():
                    print(test.getRun(runNumber).passed())
                    print("added %s to passed tests" % test.getName())
                    passedTests[test.getKey()] = test

        remainingTests = list()
        for test in self.certification.getTests():
            try:
                passedTests[test.getKey()]
            except:
                if not test.isDeleted():
                    remainingTests.append(test)


        print("Checking catalog for open tests")
        openTests = catalog.getOpenTests(self.certification)

        # filter remaining tests by open tests
        if openTests == None: # no cert is associated with the results, or skipped checking it.
            return remainingTests

        if openTests: # if there's a list, (possibly empty)
            print("The following tests are still open: %s" % (", ".join(openTests)).lower())
            tests = remainingTests
            remainingTests = list()
            for test in tests:
                if test.getName().upper() in openTests:
                    remainingTests.append(test)
        else:
            print("There are no open tests remaining in the certification")
            return list()

        return remainingTests


