# Copyright (c) 2017 Red Hat, Inc. All rights reserved. This copyrighted material
# is made available to anyone wishing to use, modify, copy, or
# redistribute it subject to the terms and conditions of the GNU General
# Public License v.2.
#
# This program is distributed in the hope that it will be useful, but WITHOUT ANY
# WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
# PARTICULAR PURPOSE. See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
#
# Author: Greg Nichols

import sys
import json
from copy import deepcopy

from rhcert.services.microservice import MicroService


class RHOSPFeatures(MicroService):

    def __init__(self, environment=None, deferredCall=None):
        MicroService.__init__(self, environment, deferredCall)
        self.matrix = None
        self.components = None
        self.current = False

    def getURL(self):
        return "rhosp-features"
    def getHeaders(self):
        return  {"Accept": "application/json"}
    def getCacheFileName(self):
        return "rhosp-features.json"

    def getAll(self):
        """ returns the entire product name dictionary """

        # already got it
        if self.components:
            return self.components

        # get it from the service
        # self.componentsJson = self.call()
        # if self.componentsJson:
        #    self.matrix = self.componentsJson.json()
        #    self.components = self.matrix.get("components")
        #    self.current = True
        #    return self.components

        # get it from the cache
        self.componentsJson = self.getCache()
        self.matrix = json.loads(self.componentsJson)
        self.components = self.matrix.get("components")
        return self.components

    def getAllJson(self):
        self.getAll()
        return self.componentsJson

    def getComponent(self, componentName, rhospVersionID=0):
        rhospVersionID = int(rhospVersionID)
        self.getAll()
        for component in self.components:
            if str(component["name"]) == str(componentName):
                # if version filtering:
                if rhospVersionID and not self.__filterVersion(component, rhospVersionID):
                    return self.__filter(component, rhospVersionID)
                else:
                    return component
        return None

    def __filter(self, component, rhospVersionID):
        if not rhospVersionID:
            return component
        componentCopy = deepcopy(component)
        tests = componentCopy.get("tests")
        for test in list(tests):
            if self.__filterVersion(test, rhospVersionID):
                tests.remove(test)
                continue

            features = test.get("features")
            for feature in list(features):
                if self.__filterVersion(feature, rhospVersionID):
                    features.remove(feature)
        return componentCopy

    def __filterVersion(self, thing, rhospVersionID):
        if (thing.get("startVersion") and rhospVersionID < thing.get("startVersion")):
            return True

        if (thing.get("endVersion") and rhospVersionID > thing.get("endVersion")):
            return True

        return False # not filtered out

if __name__ == "__main__":
    sys.exit(1)
