# Copyright (c) 2016 Red Hat, Inc. All rights reserved. This copyrighted material
# is made available to anyone wishing to use, modify, copy, or
# redistribute it subject to the terms and conditions of the GNU General
# Public License v.2.
#
# This program is distributed in the hope that it will be useful, but WITHOUT ANY
# WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
# PARTICULAR PURPOSE. See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
#
# Author: Greg Nichols
import os
import sys
import json
from rhcert.compatability import StringIO
from rhcert.environment import Environment
from rhcert.command import Command
from rhcert.services.microservice import MicroService
from rhcert.tags import TestResult

class ValidateRPMs(MicroService):

    def __init__(self, product=None, version=None, packages=None, environment=None, deferredCall=None):
        MicroService.__init__(self, environment, deferredCall)
        self.product = product
        self.version = version
        self.packages = packages

    def getURL(self):
        return "playback/validate-rpms"

    def getHeaders(self):
        return {"Content-Type": "application/json"}

    def getMethod(self):
        return "POST"

    def getPayload(self):
        if self.product and self.version and self.packages:
            product_version = "%s-%s" % (self.product, self.version)
            return {"release": product_version,
                    "packages": list(filter(None, self.packages))}
        return MicroService.getPayload(self)

    def getCacheFileName(self):
        return None # no caching

    def update(self, outputDocument, runDocument):
        response = self.call()
        if not response:
            return False # can't update

        package_data = response.json()
        log = StringIO()
        log.write("\nUpdating Deferred Test: " + self.__class__.__name__
                + "\n--------------------------------------------\n")
        previousResult = TestResult(outputDocument.getSummary())
        if package_data['non_red_hat_packages']:
            log.write("Warning: Non Red Hat packages found.\n")
            non_rh_packages = package_data['non_red_hat_packages']
        else:
            log.write("Passed: All installed packages are from Red Hat product.\n")
            outputDocument.appendLog(log.getvalue())
            # Can't upgrade FAIL from package validation
            if previousResult == TestResult.REVIEW:
                outputDocument.setSummary(TestResult.PASS)
                return TestResult.PASS
            else:
                return previousResult


        log.write("\nFollowing non-Red Hat packages are installed:\n%s\n\n" % ("\n".join(non_rh_packages)))
        log.write("\nNeeds Review: Require explanations on why these packages are installed.")

        outputDocument.appendLog(log.getvalue())
        return previousResult


if __name__ == "__main__":
    if unit_test():
        sys.exit(0)
    sys.exit(1)
