#!/usr/bin/env python
# Copyright (c) 2019 Red Hat, Inc. All rights reserved.
# This copyrighted material is made available to anyone
# wishing to use, modify, copy, or redistribute it subject
# to the terms and conditions of the GNU General
# Public License v.2.
#
# This program is distributed in the hope that it will be
# useful, but WITHOUT ANY WARRANTY; without even the implied
# warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
# MA 02110-1301, USA.
#
# Author: Pooja Tiwari <ptiwari@redhat.com>
#         Chandan Kumar <chkumar@redhat.com>
#         Javed Alam <jalam@redhat.com>

""" Base for rhcert/policy definitions"""


def get_policy():
    """
    Function to get policy
    """
    return {
        "OS_ARCH": {
            # rhel6 supported architectures over hypervisors.
            "el6": {
                "x86": ["kvm", "lkvm", "qemu", "rhev", "vmware", "hyperv"],
                "i386": ["kvm", "lkvm", "qemu", "rhev", "vmware", "hyperv"],
                "i686": ["kvm", "lkvm", "qemu", "rhev", "vmware", "hyperv"],
                "x86_64": ["kvm", "lkvm", "qemu", "rhev", "vmware", "hyperv"],
                "ppc": ["ibm_power-lpar_shared", "ibm_power-lpar_dedicated"],
                "ppc64": ["ibm_power-lpar_shared", "ibm_power-lpar_dedicated"]
            },
            # rhel7 supported architectures over hypervisors.
            "el7": {
                "x86_64": ["kvm", "lkvm", "qemu", "rhev", "vmware", "hyperv"],
                "ppc": ["rhev", "ibm_power-lpar_shared", "ibm_power-lpar_dedicated"],
                "ppc64": ["rhev", "ibm_power-lpar_shared", "ibm_power-lpar_dedicated"],
                "ppc64le": ["rhev", "ibm_power-lpar_shared", "ibm_power-lpar_dedicated", "baremetal"]
            },
            # rhel8 supported architectures over hypervisors.
            "el8": {
                "x86_64": ["kvm", "lkvm", "qemu", "rhev", "vmware", "hyperv"],
                "ppc64le": ["rhev", "ibm_power-lpar_shared", "ibm_power-lpar_dedicated", "baremetal"],
                "aarch64": ["baremetal"],
                "s390x": ["kvm", "ibm_systemz", "ibm_systemz-zvm", "baremetal"]
            }
        },
        "OS_RELEASE": ["Red", "Hat"],
        "RH_RPM_CHECK": ["Red Hat, Inc", "build.eng.bos.redhat.com"],
        "RH_SUBSCRIPTION_VAL": ["Subscribed"],
        "RH_VIRT_VAL": ["kvm", "lkvm", "qemu", "vmware", "rhev", "hyperv", "ibm_power-lpar_shared",
                        "ibm_power-lpar_dedicated", "baremetal"],
        "RH_URLS": ["bos.redhat.com", "rhui", "satellite", "ftp.redhat.com"],
        "RH_REPOS": {"REQUIRED": {"RHEL-6": [], "RHEL-7": [],
                                  "RHEL-8": ["AppStream", "BaseOS"]},
                     },
        "RH_CONTAINER_REGISTRIES": {"PRIMARY": "registry.redhat.io", "OPTIONAL": "registry.connect.redhat.com"},
        "RH_EXCEPT_KWS": ["BETA", "RHUI"],
        "RH_EXCEPT_PKGS": ["gpg-pubkey"],
        "RUN_LEVELS": ["3", "4", "5"],
        "PASSWORD_HASH": ["sha512"],
        "SELINUX": ["enforcing"],
        "FILE_TYPE": {"RHEL-6": ["ext3", "ext4"], "RHEL-7": ["ext4", "xfs"], "RHEL-8": ["xfs"]},
        "FILESYS_SIZE": [6144],
        # Sizes below are in GB
        "BOOT_PARTITION_SIZE": 1,
        "ROOT_PARTITION_SIZE": 10,
        "RAM_PER_CORE_THRESHOLD": 1,
        "SERVICE": ["firewalld", "sshd", "iptables"],
        "YUM_PLUGIN": ["1"]
    }
