from rhcert.redhatrelease import RedHatRelease
from rhcert.services.rpmfreshness import RpmFreshness

try:  # python2
    from ConfigParser import ConfigParser
except ImportError:  # python3
    from configparser import ConfigParser

from rhcert.tags import TestResult
from rhcert.test import SubTest
from rhcert.suites.rhcert.supportability import Utility


class RPMFreshnessTest(SubTest):

    def __init__(self, test):
        SubTest.__init__(self, test, "RPM Freshness",
                         "Test RPM Freshness")
        self.installed_packages = list()
        self.release = RedHatRelease()


    def get_list_of_installed_packages(self):
        """
        Returns list of installed packages.
        """

        data = Utility().command_execute("rpm -qa")
        self.installed_packages = data.split("\n")[:-1]

    def runSubTest(self):
        """
        Cases with their return values:

        microservice is not reachable:
            NEEDS REVIEW (manual review required.)
        microservice returns no updates:
            TRUE (PASS)
        microservice returns list of security
        vulnerabilities (critical/important):
            WARNING (Display list of vulnerabilities)
        """

        if not self.release.text:
            print("Error: Unsupported Operating System.")
            return False
        self.get_list_of_installed_packages()
        major_dot_minor_version = ("%s.%s %s" % (self.release.getVersion(),
                                                        self.release.getUpdate(),
                                                        self.release.getLabel())).strip()
        product_short_name = "RHEL"

        # TODO: product short name should come from 'product name service' (RHCAAS-144)
        # product_short_name = MicroServices().product_shortname(self.release.text)

        rpm_freshness = RpmFreshness(
            product_short_name,
            major_dot_minor_version,
            self.installed_packages)
        security_updates = rpm_freshness.call()
        if not security_updates:
            print((
                "\nNeeds Review: Check for the critical/important security " +
                "vulnerabilities (if any) for the installed packages."))
            self.deferredServices.append(rpm_freshness)
            return TestResult.REVIEW

        security_updates = security_updates.json()
        if not security_updates['updates']:
            print("RPM Freshness successful.")
            return TestResult.PASS
        else:
            _msg = str()
            # check for critical/important security vulnerabilities
            pkg_width = 20
            pkg_version_width = 30
            for package, update in security_updates['updates'].items():
                if update['severity'] in ['Critical', 'Important']:
                    _msg = (
                        _msg +
                        "\n|{0}|{1}|{2}|").format(
                        package.ljust(pkg_width),
                        update['installed_version'].ljust(pkg_version_width),
                        update['version_available'].ljust(pkg_version_width))
            if not _msg:
                print("RPM Freshness successful.")
                return True
            else:
                print("Warning: Following packages needs to be updated:")
                separator = "+{0}+{1}+{2}+".format("-" *
                                                pkg_width, "-" *
                                                pkg_version_width, "-" *
                                                pkg_version_width)
                print(separator)
                print("|{0}|{1}|{2}|".format("Package".ljust(pkg_width),
                                          "Installed Version".ljust(pkg_version_width),
                                          "Available Version".ljust(pkg_version_width)))
                print(separator + _msg)
                print(separator + "\n")
                return TestResult.WARN