# Copyright (c) 2012 Red Hat, Inc. All rights reserved. This copyrighted material
# is made available to anyone wishing to use, modify, copy, or
# redistribute it subject to the terms and conditions of the GNU General
# Public License v.2.
#
# This program is distributed in the hope that it will be useful, but WITHOUT ANY
# WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
# PARTICULAR PURPOSE. See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
#
# Author: Greg Nichols
#
# Workflow is the base class for proxies to CWE

import datetime
import os
from rhcert.tags import Constants
from rhcert.services.productnameservice import ProductNameService
from rhcert.rhcertStore import RedHatCertificationStore
from rhcert.environment import Environment


class Config(object):
    logFile = None

    def __init__(self, environment=Environment(), rhcertStore=None, debug=Constants.low, debugLog=None):
        self.environment = environment
        self.rhcertStore = rhcertStore
        self.debug = debug
        self.productNameService = ProductNameService()
        self.debugLog = debugLog


    @classmethod
    def __getLog(cls, environment):
        """ rhcert.workflow is used in both WUI and CLI installations.
            open the log file in /var/www/rhcert/store if possible, /var/log/rhcert if not
        """
        if cls.logFile:
            return cls.logFile
        # otherwise
        logFileDirectories = [os.path.join(environment.getStoreDirectory(), "log"), environment.getLogDirectory()]
        logFileName = "workflow-%s.log" % os.getpid()
        errors = list()
        for directory in logFileDirectories:
            try:
                if not os.path.exists(directory): # add log directory to store if missing
                    os.mkdir(directory)
                cls.logFile = open(os.path.join(directory, logFileName), "w")
                cls.logFile.write("\nStarting debug logging at %s\n" % datetime.datetime.now())
                break
            except Exception as error:
                pass # expected: /var/www/rhcert/store does not exist if redhat-certification is not installed.
                errors.append(error)
                cls.logFile = None
        if cls.logFile:
            return cls.logFile

        print("Error: could not open log file")
        for error in errors: print(error)
        return None


    def __getDebugLog(self):
        if self.debugLog:
            return self.debugLog
        return Config.__getLog(self.environment)

    def log(self, data, logLevel=Constants.off):
        """ write data to workflow log """
        levelMap = {Constants.off: 0, Constants.low: 1, Constants.high: 2}
        if levelMap[self.debug] >= levelMap[logLevel]:
            if self.__getDebugLog():
                try:
                    self.__getDebugLog().write(str(data))
                    self.__getDebugLog().write("\n")
                    self.__getDebugLog().flush()
                except Exception as error:
                    self.__getDebugLog().write("Error Logging: %s\n" % error)
                    self.__getDebugLog().flush()
