# Copyright (c) 2017 Red Hat, Inc. All rights reserved. This copyrighted material
# is made available to anyone wishing to use, modify, copy, or
# redistribute it subject to the terms and conditions of the GNU General
# Public License v.2.
#
# This program is distributed in the hope that it will be useful, but WITHOUT ANY
# WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
# PARTICULAR PURPOSE. See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
#
# Author: Greg Nichols
#
import rhcert.version

class WorkflowCredentials(object):
    jwt = "jwt"

    def __init__(self, tokens):
        self.mode = None
        self.username = None
        self.login_session = None
        self.access_token = None
        self.refresh_token = None
        self.password = None
        self.login = None
        self.update(tokens)


    def update(self, tokens):
        for attribute in ["username", "access_token", "refresh_token", "password"]:
            if tokens.get(attribute):
                self.__dict__[attribute] = tokens.get(attribute)

        self.password = self.access_token

        # compatability
        self.mode = WorkflowCredentials.jwt
        self.api_version = rhcert.version.version
        self.account_type = "sso"
        if self.username:
            self.login = self.username
        elif self.login:
            self.username = self.login

    def isLoggedIn(self):
        if (self.username and self.password):
            return True
        return False

    def getParameters(self):
        """ return a dict copy of all parameters """
        return self.__removeNoneValues(self.__dict__.copy())

    def getUserName(self):
        return self.username
    def getPassword(self):
        return self.password
    def getAccessToken(self):
        return self.access_token
    def getRefreshToken(self):
        return self.refresh_token
    def getMode(self):
        return self.mode
    def getUserNamePassword(self):
        return {"username": self.username, "login": self.login, "password": self.password}

    def __removeNoneValues(self, parameters):
        notNone = dict()
        for (name, value) in parameters.items():
            if value == None:
                continue
            notNone[name] = value
        return notNone
