# Copyright (c) 2017 Red Hat, Inc. All rights reserved. This copyrighted material
# is made available to anyone wishing to use, modify, copy, or
# redistribute it subject to the terms and conditions of the GNU General
# Public License v.2.
#
# This program is distributed in the hope that it will be useful, but WITHOUT ANY
# WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
# PARTICULAR PURPOSE. See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
#
# Author: Greg Nichols
#
import sys

import rhcert.version
from rhcert.tags import Constants
from rhcert.workflow.workflow import Workflow


class Engine(Workflow):
    """ non-object CWE calls """

    def __init__(self, config):
        Workflow.__init__(self, config)

    def uploadFileToCertification(self, certificationID, isSpec, fileDescription, fileName, fileData, content_type):
        self.id = certificationID
        self.isSpec = isSpec
        self.fileDescription = fileDescription
        self.fileName = fileName
        self.fileData = fileData
        self.mimetype = content_type
        self.idType = "certification"
        return self.__fileUpload()

    def __fileUpload(self):
        self.clearErrors()
        self.fileData = self.fileData.encode("base64")
        params = {
            "id": self.id,
            "is_spec": self.isSpec,
            "file_name": self.fileName,
            "description": self.fileDescription,
            "content_type": self.mimetype,
            "data": self.fileData,
            "type": self.idType
        }
        response = self.callProceedure(params, "File.upload")
        if self.getErrors():
            self.pushError("Error: could not upload file:")
        return response

    def downloadFileFromCertification(self, certificationID, fileID):
        self.id = certificationID
        self.fileID = fileID
        self.idType = "certification"
        return self.__downloadFile()

    def __downloadFile(self):
        self.clearErrors()
        params = {
            "id": self.id,
            "type": self.idType,
            "file_id": self.fileID
        }
        response = self.callProceedure(params, "File.download")
        if self.getErrors():
            self.pushError("Error: could not download file:")
        return response
